@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.71 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: amenu.c,v 1.75 2008/04/16 16:12:34 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -237,14 +237,30 @@ void	init_auto_menu( void )
 	init_auto_mark_all_appoint();
 	init_auto_mark_all_mbr();
 
-	for( i = 0; i < LS_MBR_MAX_N; i++ ){
+	for( i = 0; i < LS_MBR_MAX_N; i++ )
 		clip_board_large[i] = ls_auto_mark[i][0];
-
-		str_nz_cpy( clip_board_ttl,
-				msg_ttl_auto_mark[0],
-				MSG_TTL_AUTO_MARK_MAX_LEN );
-	}
 	clip_board_small = ls_auto_mark[0][0];
+	str_nz_cpy( clip_board_ttl,
+			msg_ttl_auto_mark[0],
+			MSG_TTL_AUTO_MARK_MAX_LEN );
+}
+
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_auto_menu( void )
+{
+	long	i;
+
+	g_sel_mbr = NULL;
+	auto_mark_cur_n = 0;
+
+	for( i = 0; i < LS_MBR_MAX_N; i++ )
+		clip_board_large[i] = dflt_auto_mark_fight;
+	clip_board_small = dflt_auto_mark_fight;
+	str_nz_cpy( clip_board_ttl, "",
+			MSG_TTL_AUTO_MARK_MAX_LEN );
 }
 
 /***************************************************************
@@ -594,7 +610,7 @@ void	ver_up_auto_mark_1_1_3( void )
 
 void	cv_msg_ttl_auto_mark( char *ttl )
 {
-	static char	old_split[] = " - ";
+	const char	old_split[] = " - ";
 	char	work_left[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
 	char	work_right[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
 	char	*p;
@@ -902,13 +918,16 @@ bool_t	exec_menu_auto_mark( mbr_t *mbr )
 			flg_clr = TRUE;
 		break;
 	case AUTO_MARK_TRGT_TRAP:
+		if( !exec_menu_auto_mark_trap( mbr ) )
+			flg_clr = TRUE;
 		break;
 	case AUTO_MARK_TRGT_MBR:
 		if( !exec_menu_auto_mark_mbr( mbr ) )
 			flg_clr = TRUE;
 		break;
 	case AUTO_MARK_TRGT_UNCHANGE:
-		return TRUE;
+		flg_clr = FALSE;
+		break;
 	case AUTO_MARK_TRGT_CLEAR:
 		flg_clr = TRUE;
 		break;
@@ -985,6 +1004,8 @@ bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr )
 		break;
 	case AUTO_MARK_COND_STAGGER:
 	case AUTO_MARK_COND_OWN:
+	case AUTO_MARK_COND_IDENTIFIED:
+	case AUTO_MARK_COND_UN_IDENTIFIED:
 		return FALSE;
 	case AUTO_MARK_COND_HP_MIN:
 		mnstr = get_mnstr_hp_min( mbr->x, mbr->y );
@@ -1091,6 +1112,12 @@ bool_t	exec_menu_auto_mark_item( mbr_t *mbr )
 	case AUTO_MARK_COND_OWN:
 		item = get_item_own( mbr, act_kind, TRUE );
 		break;
+	case AUTO_MARK_COND_IDENTIFIED:
+		item = get_item_identified( mbr, act_kind, TRUE );
+		break;
+	case AUTO_MARK_COND_UN_IDENTIFIED:
+		item = get_item_un_identified( mbr, act_kind, TRUE );
+		break;
 	case AUTO_MARK_COND_HP_MIN:
 	case AUTO_MARK_COND_HP_MAX:
 	case AUTO_MARK_COND_MP_MIN:
@@ -1188,6 +1215,8 @@ bool_t	exec_menu_auto_mark_door( mbr_t *mbr )
 		break;
 	case AUTO_MARK_COND_STAGGER:
 	case AUTO_MARK_COND_OWN:
+	case AUTO_MARK_COND_IDENTIFIED:
+	case AUTO_MARK_COND_UN_IDENTIFIED:
 	case AUTO_MARK_COND_HP_MIN:
 	case AUTO_MARK_COND_HP_MAX:
 	case AUTO_MARK_COND_MP_MIN:
@@ -1223,6 +1252,103 @@ bool_t	exec_menu_auto_mark_door( mbr_t *mbr )
 	return TRUE;
 }
 
+/***************************************************************
+* 櫤оݤ˥˥塼¹Ԥ
+* mbr_t *mbr : С
+* return : Ԥ
+***************************************************************/
+
+bool_t	exec_menu_auto_mark_trap( mbr_t *mbr )
+{
+	auto_mark_t	*am;
+	trap_t	*trap;
+	dist_t	dist;
+	act_kind_t	act_kind;
+
+	if( mbr == NULL )
+		return FALSE;
+	am = &(ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n]);
+
+	switch( am->act ){
+	case AUTO_MARK_ACT_FIGHT:
+	case AUTO_MARK_ACT_THROW:
+	case AUTO_MARK_ACT_STEAL:
+	case AUTO_MARK_ACT_TAIL:
+	case AUTO_MARK_ACT_PICK_UP:
+	case AUTO_MARK_ACT_OPEN:
+	case AUTO_MARK_ACT_CLOSE:
+	case AUTO_MARK_ACT_JAM:
+		return FALSE;
+	case AUTO_MARK_ACT_DISARM:
+		act_kind = ACT_KIND_TRAP_DISARM;
+		break;
+	case AUTO_MARK_ACT_BREAK:
+		act_kind = ACT_KIND_TRAP_BREAK;
+		break;
+	case AUTO_MARK_ACT_PEEP:
+		return FALSE;
+	case AUTO_MARK_ACT_CHK:
+		act_kind = ACT_KIND_TRAP_CHK;
+		break;
+	default:
+		return FALSE;
+	}
+
+	/* 櫤õ */
+	trap = NULL;
+	switch( am->cond ){
+	case AUTO_MARK_COND_NEAREST:
+		trap = get_trap_nearest( mbr, act_kind );
+		break;
+	case AUTO_MARK_COND_DISPERSE:
+		trap = get_trap_disperse( mbr, act_kind );
+		if( trap == NULL )
+			trap = get_trap_randm( mbr, act_kind );
+		break;
+	case AUTO_MARK_COND_STAGGER:
+	case AUTO_MARK_COND_OWN:
+		return FALSE;
+	case AUTO_MARK_COND_IDENTIFIED:
+		trap = get_trap_identified( mbr, act_kind );
+		break;
+	case AUTO_MARK_COND_UN_IDENTIFIED:
+		trap = get_trap_un_identified( mbr, act_kind );
+		break;
+	case AUTO_MARK_COND_HP_MIN:
+	case AUTO_MARK_COND_HP_MAX:
+	case AUTO_MARK_COND_MP_MIN:
+	case AUTO_MARK_COND_MP_MAX:
+		return FALSE;
+	}
+	if( trap == NULL )
+		return FALSE;
+
+	/* ֹ礤򥻥å */
+	switch( am->dist ){
+	case AUTO_MARK_DIST_NEAR:
+		dist = DIST_NEAR;
+		break;
+	case AUTO_MARK_DIST_MEDIUM:
+		dist = DIST_MEDIUM;
+		break;
+	case AUTO_MARK_DIST_FAR:
+		dist = DIST_FAR;
+		break;
+	default:
+		return FALSE;
+	}
+
+	/* 򥻥å */
+	set_chr_act( mbr, act_kind, NULL, NULL, 0, 0 );
+
+	/* 櫤ޡ */
+	mark_trap( mbr, trap, dist );
+
+	draw_mbr_stat( mbr );
+
+	return TRUE;
+}
+
 /***************************************************************
 * Соݤ˥˥塼¹Ԥ
 * mbr_t *mbr : С
@@ -1255,6 +1381,8 @@ bool_t	exec_menu_auto_mark_mbr( mbr_t *mbr )
 		p = get_mbr_stagger( mbr );
 		break;
 	case AUTO_MARK_COND_OWN:
+	case AUTO_MARK_COND_IDENTIFIED:
+	case AUTO_MARK_COND_UN_IDENTIFIED:
 		return FALSE;
 	case AUTO_MARK_COND_HP_MIN:
 		p = get_mbr_hp_min();
@@ -1668,53 +1796,52 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 
 	/* оݤ˱ƥ˥塼ܤ̵ */
 
+	set_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "throw", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "steal", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "tail", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "open", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "disarm", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "break", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "search", FLG_MENU_HIDDEN );
+
 	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt ){
 	case AUTO_MARK_TRGT_MNSTR:
-		set_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "open", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "disarm", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "break", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "search", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "throw", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "steal", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "tail", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_ITEM:
-		set_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "throw", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "steal", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "tail", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "open", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "disarm", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "break", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "search", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_DOOR:
-		set_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "throw", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "steal", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "tail", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "open", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "disarm", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "break", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "search", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_TRAP:
-		set_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "throw", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "steal", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "tail", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "open", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "disarm", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "break", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "search", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_MBR:
-		set_flg_menu( *pp, "pick up", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "open", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "close", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "jam", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "disarm", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "break", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "peep", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "search", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "fight", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "throw", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "steal", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "tail", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_UNCHANGE:
 	case AUTO_MARK_TRGT_CLEAR:
@@ -1790,6 +1917,12 @@ char	*cb_menu_auto_mark_cond_init(
 	case AUTO_MARK_COND_OWN:
 		s = "own";
 		break;
+	case AUTO_MARK_COND_IDENTIFIED:
+		s = "identified";
+		break;
+	case AUTO_MARK_COND_UN_IDENTIFIED:
+		s = "unidentified";
+		break;
 	case AUTO_MARK_COND_HP_MIN:
 		s = "hp min";
 		break;
@@ -1807,6 +1940,12 @@ char	*cb_menu_auto_mark_cond_init(
 
 	/* оݤ˱ƥ˥塼ܤ̵ */
 
+	set_flg_menu( *pp, "nearest", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp,"disperse",  FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "identified", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "unidentified", FLG_MENU_HIDDEN );
 	set_flg_menu( *pp, "hp min", FLG_MENU_HIDDEN );
 	set_flg_menu( *pp, "hp max", FLG_MENU_HIDDEN );
 	set_flg_menu( *pp, "mp min", FLG_MENU_HIDDEN );
@@ -1814,23 +1953,34 @@ char	*cb_menu_auto_mark_cond_init(
 
 	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt ){
 	case AUTO_MARK_TRGT_DOOR:
+		clr_flg_menu( *pp, "nearest", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp,"disperse",  FLG_MENU_HIDDEN );
+		break;
 	case AUTO_MARK_TRGT_TRAP:
-		set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "nearest", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp,"disperse",  FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "identified", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "unidentified", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_ITEM:
-		set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "nearest", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp,"disperse",  FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "identified", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "unidentified", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_MNSTR:
-		set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
-		set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "nearest", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp,"disperse",  FLG_MENU_HIDDEN );
 		clr_flg_menu( *pp, "hp min", FLG_MENU_HIDDEN );
 		clr_flg_menu( *pp, "hp max", FLG_MENU_HIDDEN );
 		clr_flg_menu( *pp, "mp min", FLG_MENU_HIDDEN );
 		clr_flg_menu( *pp, "mp max", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_MBR:
-		set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "nearest", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp,"disperse",  FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
 		clr_flg_menu( *pp, "hp min", FLG_MENU_HIDDEN );
 		clr_flg_menu( *pp, "hp max", FLG_MENU_HIDDEN );
 		clr_flg_menu( *pp, "mp min", FLG_MENU_HIDDEN );
@@ -2713,6 +2863,10 @@ char	*get_msg_menu_auto_mark_edit_cond( mbr_t *mbr )
 		return MSG_MENU_AUTO_MARK_COND_STAGGER;
 	case AUTO_MARK_COND_OWN:
 		return MSG_MENU_AUTO_MARK_COND_OWN;
+	case AUTO_MARK_COND_IDENTIFIED:
+		return MSG_MENU_AUTO_MARK_COND_IDENTIFIED;
+	case AUTO_MARK_COND_UN_IDENTIFIED:
+		return MSG_MENU_AUTO_MARK_COND_UN_IDENTIFIED;
 	case AUTO_MARK_COND_HP_MIN:
 		return MSG_MENU_AUTO_MARK_COND_HP_MIN;
 	case AUTO_MARK_COND_HP_MAX:
