@@ -5,8 +5,9 @@ extern "C" {
 #endif
 
 void	init_chr( void );
+void	reset_static_chr( void );
 void	exec_all_phase( void );
-void	draw_phase( void );
+void	draw_phase( bool_t flg_first_phase );
 void	move_phase_chr( chr_t *chr );
 void	act_phase_chr( chr_t *chr );
 bool_t	chk_can_act_chr( chr_t *chr );
