@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.c,v 1.74 2008/04/03 08:17:01 bowkenken Exp $
+* $Id: curs.c,v 1.76 2008/04/30 23:44:50 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -139,6 +139,14 @@ void	init_curs( void )
 	curs_attrset_dflt();
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_curs( void )
+{
+}
+
 /***************************************************************
 * ɽν
 * return : Ȥ뤫
@@ -162,7 +170,7 @@ bool_t	init_curs_color( void )
 		return TRUE;
 	}
 
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 # if	HAVE_HAS_COLORS
 	if( g_flg_cui && !has_colors() ){
 		flg_color = FALSE;
@@ -182,7 +190,7 @@ bool_t	init_curs_color( void )
 	flg_color = FALSE;
 	return FALSE;
 # endif	/* HAVE_START_COLOR */
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 
 	flg_color = TRUE;
 	for( n = 0; n < CURS_ATTR_MAX_N; n++ ){
@@ -204,7 +212,7 @@ bool_t	init_curs_color( void )
 
 bool_t	init_curs_color_pair( curs_attr_t *p, short pair_n )
 {
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( !flg_color )
 		return FALSE;
 
@@ -212,7 +220,7 @@ bool_t	init_curs_color_pair( curs_attr_t *p, short pair_n )
 	if( g_flg_cui )
 		init_pair( pair_n, p->fg, p->bg );
 # endif	/* HAVE_INIT_PAIR */
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 
 	p->color_pair_n = pair_n;
 
@@ -314,7 +322,7 @@ void	curs_clearok( WINDOW *win, bool_t bf )
 {
 	flg_curs++;
 
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( flg_curs == 1 ){
 		if( chk_curs() ){
 			if( g_flg_cui ){
@@ -323,7 +331,7 @@ void	curs_clearok( WINDOW *win, bool_t bf )
 			ena_curs();
 		}
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 }
 
 /***************************************************************
@@ -334,7 +342,7 @@ void	curs_initscr( void )
 {
 	flg_curs++;
 
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( flg_curs == 1 ){
 		if( chk_curs() ){
 			if( g_flg_cui ){
@@ -344,7 +352,7 @@ void	curs_initscr( void )
 			init_curs_color();
 		}
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 }
 
 /***************************************************************
@@ -355,14 +363,14 @@ void	curs_endwin( void )
 {
 	if( flg_curs == 1 ){
 
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 		if( chk_curs() ){
 			dis_curs();
 			if( g_flg_cui ){
 				endwin();
 			}
 		}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 
 #ifdef	D_DOS
 		curs_move( get_max_line(), 0 );
@@ -381,7 +389,7 @@ void	curs_endwin( void )
 
 void	curs_keypad( WINDOW *win, bool_t bf )
 {
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( g_flg_use_keypad ){
 		if( chk_curs() ){
 # if	HAVE_KEYPAD
@@ -391,7 +399,7 @@ void	curs_keypad( WINDOW *win, bool_t bf )
 # endif	/* HAVE_KEYPAD */
 		}
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 }
 
 /***************************************************************
@@ -403,14 +411,14 @@ void	curs_refresh( void )
 	if( !chk_curs_draw() )
 		return;
 
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( chk_curs() ){
 		if( g_flg_cui ){
 			refresh();
 			return;
 		}
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 
 	if( g_flg_cui )
 		fflush( OUT_FP );
@@ -480,7 +488,7 @@ void	curs_attrset( long at )
 	if( !chk_curs_draw() )
 		return;
 
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( chk_curs() ){
 # if	HAVE_ATTRSET
 		if( g_flg_cui ){
@@ -489,7 +497,7 @@ void	curs_attrset( long at )
 # endif	/* HAVE_ATTRSET */
 		return;
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 
 #if	D_DOS
 	if( g_flg_cui ){
@@ -523,7 +531,7 @@ void	curs_attron( long at )
 	if( !chk_curs_draw() )
 		return;
 
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( chk_curs() ){
 # if	HAVE_ATTRON
 		if( g_flg_cui ){
@@ -532,7 +540,7 @@ void	curs_attron( long at )
 # endif	/* HAVE_ATTRON */
 		return;
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 
 #if	FLG_PRINT_REVERSE
 	if( g_flg_cui ){
@@ -552,7 +560,7 @@ void	curs_attroff( long at )
 	if( !chk_curs_draw() )
 		return;
 
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( chk_curs() ){
 # if	HAVE_ATTROFF
 		if( g_flg_cui ){
@@ -561,7 +569,7 @@ void	curs_attroff( long at )
 # endif	/* HAVE_ATTROFF */
 		return;
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 
 #if	FLG_PRINT_REVERSE
 	if( g_flg_cui ){
@@ -587,13 +595,13 @@ curs_attr_t	*get_curs_attr( void )
 
 void	curs_echo( void )
 {
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( chk_curs() ){
 		if( g_flg_cui ){
 			echo();
 		}
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 }
 
 /***************************************************************
@@ -602,13 +610,13 @@ void	curs_echo( void )
 
 void	curs_noecho( void )
 {
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( chk_curs() ){
 		if( g_flg_cui ){
 			noecho();
 		}
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 }
 
 /***************************************************************
@@ -617,13 +625,13 @@ void	curs_noecho( void )
 
 void	curs_cbreak( void )
 {
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( chk_curs() ){
 		if( g_flg_cui ){
 			cbreak();
 		}
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 }
 
 /***************************************************************
@@ -632,13 +640,13 @@ void	curs_cbreak( void )
 
 void	curs_nocbreak( void )
 {
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( chk_curs() ){
 		if( g_flg_cui ){
 			nocbreak();
 		}
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 }
 
 /***************************************************************
@@ -647,13 +655,13 @@ void	curs_nocbreak( void )
 
 void	curs_raw( void )
 {
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( chk_curs() ){
 		if( g_flg_cui ){
 			raw();
 		}
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 }
 
 /***************************************************************
@@ -662,13 +670,13 @@ void	curs_raw( void )
 
 void	curs_noraw( void )
 {
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( chk_curs() ){
 		if( g_flg_cui ){
 			noraw();
 		}
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 }
 
 /***************************************************************
@@ -693,14 +701,14 @@ void	curs_move( int scrn_y, int scrn_x )
 		return;
 #endif	/* ! D_DOS */
 
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( chk_curs() ){
 		if( g_flg_cui ){
 			move( scrn_y, scrn_x );
 		}
 		return;
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 
 #ifdef	D_DOS
 	if( g_flg_cui ){
@@ -735,7 +743,7 @@ void	curs_printw( char *s, ... )
 	if( !chk_curs_draw() )
 		return;
 
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( chk_curs() ){
 		va_start( argptr, s );
 		vwprintw( stdscr, s, argptr );
@@ -743,7 +751,7 @@ void	curs_printw( char *s, ... )
 
 		return;
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 
 	va_start( argptr, s );
 	vfprintf( OUT_FP, s, argptr );
@@ -759,14 +767,15 @@ void	curs_clear( void )
 	if( !chk_curs_draw() )
 		return;
 
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( chk_curs() ){
 		if( g_flg_cui ){
+			curs_attrset_dflt();
 			clear();
 		}
 		return;
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 
 #ifdef	D_X68K
 	if( g_flg_cui ){
@@ -802,7 +811,7 @@ int	curs_getch( void )
 
 	c = '\0';
 
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 
 	if( !flg_getc ){
 		if( chk_curs() ){
@@ -811,7 +820,7 @@ int	curs_getch( void )
 		}
 	}
 
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 
 #ifdef	D_DOS
 
@@ -850,14 +859,14 @@ void	curs_getnstr( char *s, int len )
 	if( !chk_curs_draw() )
 		return;
 
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( chk_curs() ){
 # if	HAVE_GETNSTR
 		getnstr( s, len );
 		return;
 # endif	/* HAVE_GETNSTR */
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 
 	fgets( buf, sizeof( buf ) - 1, stdin );
 	str_nz_cpy( s, buf, len );
@@ -886,11 +895,11 @@ long	get_max_line( void )
 	if( !chk_flg_screen_size_auto() )
 		return get_screen_size_lines();
 
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H || HAVE_CURSES_H
 	if( chk_curs() ){
 		return LINES;
 	}
-#endif	/* HAVE_LIBCURSES */
+#endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 
 #ifdef	D_DOS
 	{
