@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.h,v 1.34 2008/04/03 08:17:01 bowkenken Exp $
+* $Id: curs.h,v 1.35 2008/04/30 21:30:50 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CURS_H
@@ -38,7 +38,12 @@
 #include	"extern.h"
 #include	"msg.h"
 
-#if	HAVE_LIBCURSES
+#if	HAVE_NCURSES_H
+# include	<ncurses.h>
+# ifndef	COLOR_WHITE
+#  include	"curs-def.h"
+# endif	/* COLOR_WHITE */
+#elif	HAVE_CURSES_H
 # include	<curses.h>
 # ifndef	COLOR_WHITE
 #  include	"curs-def.h"
