@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw.h,v 1.57 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: draw.h,v 1.59 2008/05/05 12:43:44 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_H
@@ -215,6 +215,13 @@ typedef unsigned long	flg_vfx_mnstr_t;
 #define	VFX_WAIT_MIN_N	1
 #define	VFX_WAIT_MAX_N	200
 
+/***************************************************************
+* ޥɡ
+***************************************************************/
+
+#define	CMD_KEY_IDLE	'|'
+#define	CMD_KEY_CONT_EXEC	','
+
 /***************************************************************
 * ơ֥
 ***************************************************************/
@@ -271,6 +278,7 @@ typedef enum {
 	DATA_N_STAT_SENSE_INVISIBLE,
 
 	DATA_N_STORE_LIGHT,
+	DATA_N_GRAPH_FILE,
 
 	DATA_N_LEV_LEFT,
 	DATA_N_EXP_LEFT,
