@@ -4,6 +4,7 @@
 extern "C" {
 #endif
 
+void	reset_static_fight( void );
 bool_t	fight_bash( chr_t *chr, chr_t *chr2, attack_t *dflt_attack );
 bool_t	set_attack_chr_bash(
 	chr_t *chr, attack_t *attack, long range, bool_t flg_ave
@@ -67,6 +68,13 @@ rate_t	get_crtcl( chr_t *o_p, chr_t *d_p, const attack_t *attack );
 rate_t	get_wpn_crtcl( chr_t *p, const attack_t *attack );
 rate_t	get_armor_crtcl( chr_t *p );
 bool_t	chk_ninja_crtcl( chr_t *o_p, chr_t *d_p );
+rate_t	add_hit( long n );
+rate_t	add_wpn_crtcl( long n );
+rate_t	add_dam( long n );
+rate_t	add_dam_two_handed_wpn( mbr_t *mbr, item_t *wpn );
+rate_t	add_def( long n );
+rate_t	add_armor_crtcl( long n );
+rate_t	add_ac( long n );
 long	get_dam_stick( chr_t *p );
 long	get_dam_spell( chr_t *p, abl_kind_t abl_main, abl_kind_t abl_sub );
 rate_t	get_resi_def( chr_t *p, resi_kind_t resi );
