@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile-tab.h,v 1.20 2008/02/14 08:44:16 bowkenken Exp $
+* $Id: gfile-tab.h,v 1.21 2008/04/12 12:21:28 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_TAB_H
@@ -350,6 +350,12 @@ auto_mark_cond_t	g_am_cond_trans_tab[] = {
 
 	/* 1  MP ¿ */
 	AUTO_MARK_COND_MP_MAX,
+
+	/* ̺ */
+	AUTO_MARK_COND_IDENTIFIED,
+
+	/* ̤ */
+	AUTO_MARK_COND_UN_IDENTIFIED,
 };
 
 /***************************************************************
