@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.101 2008/01/31 20:24:31 bowkenken Exp $
+* $Id: gmain.c,v 1.104 2008/04/18 18:33:40 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -131,6 +131,157 @@ char	str_usage[] = {
 	"  -h, --help               display this help and exit\n"
 };
 
+/***************************************************************
+* Τν
+***************************************************************/
+
+void	init_game( void )
+{
+	dun_t	*dun;
+
+	/* ƽθƤֽ֤˵դ */
+
+	g_flg_init = FALSE;
+
+	reset_static();
+
+	init_signal();
+	init_scrn();
+
+	srandm( (long)time( NULL ) );
+
+	init_scene();
+	init_turn();
+
+	init_msg();
+	init_draw();
+	init_replay();
+
+	init_game_file();
+
+	init_var_menu();
+	init_var_main_menu();
+	init_var_misc_menu();
+
+	if( !load_game_conf() )
+		g_flg_measure_clk_tck = TRUE;
+	overwrite_arg();
+
+	ena_scrn( TRUE );
+	ena_curs_draw();
+	wipe_all();
+
+	init_dun();
+	init_item();
+	init_trap();
+	init_fx();
+	init_spell();
+	init_chr();
+	init_town();
+	init_menu();
+	init_town_menu();
+	init_auto_menu();
+	init_misc_menu();
+	init_main_menu();
+	init_request();
+
+	init_mbr_formation();
+
+	if( g_flg_debug )
+		init_spell_debug();
+	else
+		init_spell_dflt();
+	init_spell_nin();
+
+	if( g_flg_debug )
+		set_flg_no_save( TRUE );
+
+	if( g_flg_measure_clk_tck )
+		measure_clk_tck();
+
+	dun = get_dun();
+	dun->lev = 0;
+	up_dun( 0 );
+
+	g_flg_init = TRUE;
+}
+
+/***************************************************************
+* ⥸塼Υƥåѿꥻå
+***************************************************************/
+
+void	reset_static( void )
+{
+	reset_static_auto_menu();
+	reset_static_chr();
+	reset_static_curs();
+	reset_static_draw();
+	reset_static_dun();
+	reset_static_fight();
+	reset_static_fx();
+	reset_static_game_file();
+	reset_static_game_main();
+	reset_static_misc_menu();
+	reset_static_item();
+	reset_static_menu();
+	reset_static_misc();
+	reset_static_main_menu();
+	reset_static_mnstr_act();
+	reset_static_mnstr();
+	reset_static_msg();
+	reset_static_nest_flg();
+	reset_static_party();
+	reset_static_pet();
+	reset_static_replay();
+	reset_static_request();
+	reset_static_scene();
+	reset_static_spell();
+	reset_static_town_menu();
+	reset_static_town();
+	reset_static_trap();
+	reset_static_turn();
+
+#if	defined( D_GTK )
+#elif	defined( D_WS )
+#elif	defined( D_MFC )
+#elif	defined( D_DOS )
+	reset_static_main_dos();
+#else
+	reset_static_main_unix();
+#endif
+}
+
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_game_main( void )
+{
+}
+
+/***************************************************************
+* ᥤ󡦥롼
+***************************************************************/
+
+void	game_main( void )
+{
+	chk_scroll( TRUE );
+	redraw_all();
+
+	if( !g_flg_debug ){
+		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_1 );
+		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_2 );
+
+		menu_load_bar();
+
+		party_exit_bar();
+	}
+
+	while( 1 ){
+		chk_key( g_flg_clr_key_buf, TRUE );
+	}
+}
+
 /***************************************************************
 * ν
 ***************************************************************/
@@ -422,102 +573,6 @@ void	usage( FILE *fp )
 	fflush( fp );
 }
 
-/***************************************************************
-* Τν
-***************************************************************/
-
-void	init_game( void )
-{
-	dun_t	*dun;
-
-	/* ƽθƤֽ֤˵դ */
-
-	g_flg_init = FALSE;
-
-	init_signal();
-	init_scrn();
-
-	srandm( (long)time( NULL ) );
-
-	init_scene();
-	init_turn();
-
-	init_msg();
-	init_draw();
-	init_replay();
-
-	init_game_file();
-
-	init_var_menu();
-	init_var_main_menu();
-	init_var_misc_menu();
-
-	if( !load_game_conf() )
-		g_flg_measure_clk_tck = TRUE;
-	overwrite_arg();
-
-	ena_scrn( TRUE );
-	ena_curs_draw();
-	wipe_all();
-
-	init_dun();
-	init_item();
-	init_trap();
-	init_fx();
-	init_spell();
-	init_chr();
-	init_town();
-	init_menu();
-	init_tmenu();
-	init_auto_menu();
-	init_misc_menu();
-	init_main_menu();
-	init_request();
-
-	init_mbr_formation();
-
-	if( g_flg_debug )
-		init_spell_debug();
-	else
-		init_spell_dflt();
-	init_spell_nin();
-
-	if( g_flg_debug )
-		set_flg_no_save( TRUE );
-
-	if( g_flg_measure_clk_tck )
-		measure_clk_tck();
-
-	dun = get_dun();
-	dun->lev = 0;
-	up_dun( 0 );
-
-	g_flg_init = TRUE;
-}
-
-/***************************************************************
-* ᥤ󡦥롼
-***************************************************************/
-
-void	game_main( void )
-{
-	chk_scroll( TRUE );
-	redraw_all();
-
-	if( !g_flg_debug ){
-		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_1 );
-		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_2 );
-
-		menu_load_bar();
-
-		party_exit_bar();
-	}
-
-	while( 1 ){
-		chk_key( g_flg_clr_key_buf, TRUE );
-	}
-}
-
 /***************************************************************
 * νλ
 * long code : λ
