@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.h,v 1.52 2007/05/31 21:24:44 bowkenken Exp $
+* $Id: gmain.h,v 1.62 2008/01/11 09:12:57 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GMAIN_H
@@ -35,8 +35,12 @@
 * ᥤ
 ***************************************************************/
 
-#if	defined( D_WIN )
+#if	defined( D_GTK )
+/**/
+#elif	defined( D_WS )
 # include	"config-win.h"
+#elif	defined( D_MFC )
+# include	"config-dows.h"
 #elif	defined( D_DOS )
 # include	"lnl-dos/config-dos.h"
 #endif
@@ -131,7 +135,9 @@ typedef enum {
 
 #include	"extern.h"
 
-/* ե饰 */
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 /* CUI ⥸塼뤬Ѥߤ? */
 EXTERN bool_t	g_flg_init;
@@ -142,6 +148,12 @@ EXTERN bool_t	g_flg_cui;
 /* GUI ⡼ */
 EXTERN bool_t	g_flg_gui;
 
+/* GUI Υƥɽ⡼ */
+EXTERN bool_t	g_flg_text_mode;
+
+/* GUI Υƥɽ⡼ɤΥեȡ */
+EXTERN long	g_text_mode_point;
+
 /* եå̤γΨ */
 EXTERN rate_t	g_graph_scale_rate;
 
@@ -178,10 +190,14 @@ EXTERN bool_t	g_flg_measure_clk_tck;
 /* ֡ɻμ */
 EXTERN long	g_randm_seed_save;
 
-/* ǥХå⡼ */
-EXTERN bool_t	g_flg_debug;
-
 /* ƥμϤλ񤹤 */
 EXTERN bool_t	g_flg_send_item_exec_turn;
 
+/* ǥХå⡼ */
+EXTERN bool_t	g_flg_debug;
+
+#ifdef __cplusplus
+}
+#endif
+
 #endif	/* GMAIN_H */
