@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: inc.h,v 1.70 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: inc.h,v 1.77 2008/05/07 07:31:26 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	INC_H
@@ -51,7 +51,7 @@
 /*#include	"pet.h"*/
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
-/*#include	"trap.h"*/
+#include	"trap.h"
 /*#include	"replay.h"*/
 #include	"draw.h"
 #include	"curs.h"
@@ -75,7 +75,7 @@
 /*#include	"pet-prot.h"*/
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
-/*#include	"trap-prot.h"*/
+#include	"trap-prot.h"
 /*#include	"replay-prot.h"*/
 #include	"draw-prot.h"
 #include	"curs-prot.h"
@@ -145,6 +145,7 @@
 /*#include	"gfile-prot.h"*/
 /*#include	"msg-prot.h"*/
 
+#include	"win-kind.h"
 #include	"call-prot.h"
 
 #endif	/* CHR_C */
@@ -204,6 +205,7 @@
 /*#include	"gfile-prot.h"*/
 /*#include	"msg-prot.h"*/
 
+#include	"win-kind.h"
 #include	"call-prot.h"
 
 # ifdef	D_DOS
@@ -330,6 +332,7 @@
 #include	"gfile-prot.h"
 #include	"msg-prot.h"
 
+#include	"win-kind.h"
 #include	"call-prot.h"
 
 #include	"vfx-kind.h"
@@ -402,6 +405,7 @@
 #include	"nest-flg.h"
 #include	"nest-flg-prot.h"
 
+#include	"win-kind.h"
 #include	"call-prot.h"
 
 #endif	/* DUN_C */
@@ -524,6 +528,10 @@
 
 #ifdef	GFILE_C
 
+# ifndef	EXTERN
+#  define	EXTERN	extern
+# endif	/* EXTERN */
+
 #include	"gmain.h"
 /*#include	"misc.h"*/
 /*#include	"scene.h"*/
@@ -579,6 +587,9 @@
 # include	"GraphConfToken.h"
 #endif
 
+#include	"gfile-ver.h"
+
+#include	"win-kind.h"
 #include	"call-prot.h"
 
 #endif	/* GFILE_C */
@@ -621,6 +632,7 @@
 #include	"chr-prot.h"
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
+#include	"mnstr-act-prot.h"
 #include	"pet-prot.h"
 #include	"fight-prot.h"
 #include	"fx-prot.h"
@@ -637,6 +649,9 @@
 #include	"gfile-prot.h"
 #include	"msg-prot.h"
 
+#include	"nest-flg.h"
+#include	"nest-flg-prot.h"
+
 #include	<signal.h>
 
 #if	HAVE_GETOPT_H
@@ -663,6 +678,7 @@
 # include	"main-dows-prot.h"
 #endif	/* D_MFC */
 
+#include	"win-kind.h"
 #include	"call-prot.h"
 
 #endif	/* GMAIN_C */
@@ -722,6 +738,7 @@
 #include	"gfile-prot.h"
 #include	"msg-prot.h"
 
+#include	"win-kind.h"
 #include	"call-prot.h"
 
 #endif	/* IMENU_C */
@@ -898,6 +915,7 @@
 /*#include	"msg-prot.h"*/
 
 #include	"main-unix-prot.h"
+#include	"win-kind.h"
 #include	"call-prot.h"
 
 # endif	/* MAIN_UNIX_C */
@@ -960,6 +978,7 @@
 #include	"nest-flg.h"
 #include	"nest-flg-prot.h"
 
+#include	"win-kind.h"
 #include	"call-prot.h"
 
 #endif	/* MENU_C */
@@ -1076,6 +1095,7 @@
 #include	"gfile-prot.h"
 #include	"msg-prot.h"
 
+#include	"win-kind.h"
 #include	"call-prot.h"
 
 #endif	/* MMENU_C */
@@ -1376,7 +1396,7 @@
 /*#include	"scene.h"*/
 #include	"turn.h"
 #include	"dun.h"
-/*#include	"town.h"*/
+#include	"town.h"
 #include	"item.h"
 /*#include	"spell.h"*/
 #include	"chr.h"
@@ -1400,7 +1420,7 @@
 /*#include	"scene-prot.h"*/
 #include	"turn-prot.h"
 #include	"dun-prot.h"
-/*#include	"town-prot.h"*/
+#include	"town-prot.h"
 #include	"item-prot.h"
 /*#include	"spell-prot.h"*/
 #include	"chr-prot.h"
@@ -1608,7 +1628,7 @@
 #include	"item.h"
 #include	"spell.h"
 /*#include	"chr.h"*/
-/*#include	"party.h"*/
+#include	"party.h"
 /*#include	"mnstr.h"*/
 #include	"pet.h"
 #include	"fight.h"
@@ -1632,7 +1652,7 @@
 #include	"item-prot.h"
 #include	"spell-prot.h"
 #include	"chr-prot.h"
-/*#include	"party-prot.h"*/
+#include	"party-prot.h"
 /*#include	"mnstr-prot.h"*/
 #include	"pet-prot.h"
 #include	"fight-prot.h"
@@ -1824,6 +1844,7 @@
 /*#include	"msg-prot.h"*/
 
 #include	"main-x-prot.h"
+#include	"win-kind.h"
 #include	"call-prot.h"
 
 #include	<gtk/gtk.h>
@@ -1889,6 +1910,7 @@
 #include	"GlobalVar.h"
 
 #include	"main-dows-prot.h"
+#include	"win-kind.h"
 #include	"call-prot.h"
 
 #include	"xlnl-dows/stdafx.h"
@@ -1961,6 +1983,7 @@
 
 #include	"main-x-prot.h"
 #include	"main-gtk-prot.h"
+#include	"win-kind.h"
 #include	"call-prot.h"
 
 #endif	/* MAIN_GTK_CPP */
@@ -1980,6 +2003,7 @@
 #  include "GuiMenu.h"
 #  include "PcgDun.h"
 #  include "GraphConfToken.h"
+#  include "SelMbrGraph.h"
 #  include "GlobalVar.h"
 #  include "gmain-prot.h"
 #  include "chr-prot.h"
@@ -1993,6 +2017,7 @@
 #  include "GuiMenu.h"
 #  include "PcgDun.h"
 #  include "GraphConfToken.h"
+#  include "SelMbrGraph.h"
 #  include "GlobalVar.h"
 #  include "gmain-prot.h"
 #  include "chr-prot.h"
@@ -2006,6 +2031,7 @@
 #  include "GuiMenu.h"
 #  include "PcgDun.h"
 #  include "GraphConfToken.h"
+#  include "SelMbrGraph.h"
 #  include "GlobalVar.h"
 #  include "gmain-prot.h"
 #  include "chr-prot.h"
@@ -2018,6 +2044,7 @@
 #  include "chr-prot.h"
 # endif
 
+# include "win-kind.h"
 # include "call-prot.h"
 
 #endif	/* CALL_CPP */
@@ -2314,6 +2341,12 @@
 # include "GuiMisc.h"
 #endif /* D_GTK */
 
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "xlnl-dows/xlnl-dows.h"
+# include "xlnl-dows/InputNumDlg.h"
+#endif // D_MFC
+
 #endif	/* GUI_NUM_CPP */
 
 /***************************************************************/
