@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: misc.c,v 1.40 2007/12/05 13:20:39 bowkenken Exp $
+* $Id: misc.c,v 1.42 2008/04/16 16:12:34 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -41,6 +41,14 @@
 
 static long	randm_seed = 1;
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_misc( void )
+{
+}
+
 /***************************************************************
 * ߤ򥳥ޡեޥåʸѴ
 * long n : 
