@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.33 2008/04/06 08:00:04 bowkenken Exp $
+* $Id: mmenu.c,v 1.36 2008/04/25 23:46:01 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -92,6 +92,10 @@ static ls_equip_msg_t	ls_equip_msg[] = {
 
 /**/
 
+static long static_cb_menu_item__pre_sel_mbr_n;
+
+/**/
+
 void	init_var_main_menu( void )
 {
 	set_scroll_page();
@@ -107,6 +111,19 @@ void	init_main_menu( void )
 	g_menu_dflt_main = NULL;
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_main_menu( void )
+{
+	g_menu_dflt_main = NULL;
+
+	/**/
+
+	static_cb_menu_item__pre_sel_mbr_n = 0;
+}
+
 /**/
 
 char	*exec_menu_sel_mbr(
@@ -462,11 +479,8 @@ char	*cb_menu_exec( menu_t **pp, menu_t **dflt )
 {
 	set_menu_dflt_main( *pp );
 
-	inc_turn();
 	exec_all_phase();
 
-	call_pcg_dun_draw_turn();
-
 	return NULL;
 }
 
@@ -1280,12 +1294,14 @@ char	*cb_menu_dist_act( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_item( menu_t **pp, menu_t **dflt )
 {
-	static long pre_sel_mbr_n = 0;
+	long pre_sel_mbr_n;
 	party_t	*pty = get_party();
 	menu_t	*ls;
 	mbr_t	*mbr;
 	long	i, j, k;
 
+	pre_sel_mbr_n = static_cb_menu_item__pre_sel_mbr_n;
+
 	if( g_sel_mbr_n <= -1 )
 		g_sel_mbr_n = pre_sel_mbr_n;
 	else
@@ -2313,7 +2329,6 @@ char	*cb_menu_goto_item( menu_t **pp, menu_t **dflt )
 char	*cb_menu_move( menu_t **pp, menu_t **dflt )
 {
 	square_t	*sq;
-	square_dir_t	pre_dir;
 
 	set_menu_dflt_main( *pp );
 
@@ -2322,7 +2337,7 @@ char	*cb_menu_move( menu_t **pp, menu_t **dflt )
 	sq->pre_x = sq->x;
 	sq->pre_y = sq->y;
 
-	pre_dir = sq->dir;
+	sq->pre_dir = sq->dir;
 	sq->dir = SQUARE_DIR_MAX_N;
 
 	/* ưθ˹碌ƤΥ󥫡θꤹ */
@@ -2344,7 +2359,7 @@ char	*cb_menu_move( menu_t **pp, menu_t **dflt )
 	/* Ʊɸǥ󥫡ꤷ 90 ٤ŤĲž */
 
 	if( sq->dir == SQUARE_DIR_MAX_N ){
-		switch( pre_dir ){
+		switch( sq->pre_dir ){
 		case SQUARE_DIR_NORTH:
 			sq->dir = SQUARE_DIR_EAST;
 			break;
