@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.190 2008/02/05 19:55:44 bowkenken Exp $
+* $Id: mnstr.c,v 1.195 2008/05/09 12:58:31 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -111,6 +111,14 @@ void	init_mnstr( void )
 	reset_mnstr();
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_mnstr( void )
+{
+}
+
 /***************************************************************
 * եưȤΥ󥹥Υꥻå
 ***************************************************************/
@@ -494,11 +502,11 @@ mnstr_t	*make_mnstr_alloc(
 	else
 		p->flg_map |= FLG_MAP_CHR_NPC;
 
+	put_chr( p, x, y );
+
 	if( !make_mnstr_special( p, dun_lev ) )
 		return NULL;
 
-	put_chr( p, x, y );
-
 	return p;
 }
 
@@ -511,9 +519,9 @@ mnstr_t	*make_mnstr_alloc(
 
 bool_t	make_mnstr_special( mnstr_t *p, long dun_lev )
 {
+	static bool_t	flg_link = FALSE;
 	bool_t	ret = TRUE;
-	static long	link_n = 0;
-	mnstr_t	*p2;
+	mnstr_t	*p2, *pre_p;
 	long	n;
 	item_t	*chest;
 	long	i;
@@ -521,21 +529,27 @@ bool_t	make_mnstr_special( mnstr_t *p, long dun_lev )
 	if( p == NULL )
 		return FALSE;
 
-	link_n++;
-
 	switch( p->mnstr_kind ){
 	default:
 		break;
 	case MNSTR_KIND_GIGANTIC_CENTIPEDE:
-		if( link_n >= GIGANTIC_CENTIPEDE_LINK_N )
+		if( flg_link )
 			break;
+		flg_link = TRUE;
 
-		p2 = make_mnstr( p->x, p->y + 1, FALSE,
-				dun_lev, p->mnstr_kind );
-		if( p2 == NULL )
-			break;
-		mark_mnstr( p2, p, DIST_NEAR );
-		p2->work.link_chr = p;
+		pre_p = p;
+		for( i = 1; i < GIGANTIC_CENTIPEDE_LINK_N; i++ ){
+			p2 = make_mnstr( pre_p->x, pre_p->y + 1, FALSE,
+					dun_lev, p->mnstr_kind );
+			if( p2 == NULL )
+				break;
+			mark_mnstr( p2, pre_p, DIST_NEAR );
+			p2->work.link_chr = pre_p;
+
+			pre_p = p2;
+		}
+
+		flg_link = FALSE;
 		break;
 	case MNSTR_KIND_GARGOYLE:
 		n = 0;
@@ -581,8 +595,6 @@ bool_t	make_mnstr_special( mnstr_t *p, long dun_lev )
 		break;
 	}
 
-	link_n--;
-
 	return ret;
 }
 
@@ -2113,12 +2125,41 @@ void	exp_chr_mnstr(
 
 /***************************************************************
 * 󥹥ݤηиͤ׻
+* 󥹥Υ٥Υ롼פθ
 * mnstr_t *p : 󥹥
 * long dun_lev : 󥸥γ
 * return : и
 ***************************************************************/
 
 long	calc_mnstr_exp( mnstr_t *p, long dun_lev )
+{
+	long	dun_lev_max, dun_lev_mod;
+	long	lev_mul;
+	long	exp_max, exp_mod, exp;
+
+	dun_lev = labs( dun_lev );
+	dun_lev_max = labs( get_mnstr_lev_tab_max() );
+	dun_lev_mod = dun_lev % dun_lev_max;
+
+	lev_mul = dun_lev / dun_lev_max;
+	if( lev_mul < 0 )
+		lev_mul = 0;
+
+	exp_max = calc_mnstr_exp_sub( p, dun_lev_max );
+	exp_mod = calc_mnstr_exp_sub( p, dun_lev_mod );
+	exp = (exp_max * lev_mul) + exp_mod;
+
+	return exp;
+}
+
+/***************************************************************
+* 󥹥ݤηиͤ׻
+* mnstr_t *p : 󥹥
+* long dun_lev : 󥸥γ
+* return : и
+***************************************************************/
+
+long	calc_mnstr_exp_sub( mnstr_t *p, long dun_lev )
 {
 	long	lev;
 	long	exp;
