@@ -5,6 +5,7 @@ extern "C" {
 #endif
 
 void	init_party( void );
+void	reset_static_party( void );
 void	init_party_dflt( void );
 void	init_party_debug( void );
 item_t	*init_mbr_item(
@@ -80,6 +81,9 @@ bool_t	cmp_class( class_t *org, class_t *dst );
 void	arrange_class( long class_n, long d );
 square_t	*get_square_mbr( void );
 void	set_square_mbr( square_t *sq );
+void	get_square_pos( long *x, long *y );
+void	set_square_pos( long x, long y );
+void	unset_square_pos( void );
 
 #ifdef __cplusplus
 }
