@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.h,v 1.20 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: party.h,v 1.21 2008/04/18 16:06:54 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	PARTY_H
@@ -79,6 +79,8 @@ typedef struct {
 	long	pre_x, pre_y;
 	/* Ƥ */
 	square_dir_t	dir;
+	/* 1θƤ */
+	square_dir_t	pre_dir;
 
 	/* Ƥθ */
 	long	chr_pos_n[SQUARE_HEIGHT][SQUARE_WIDTH];
