@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: replay.c,v 1.8 2007/05/12 09:58:02 bowkenken Exp $
+* $Id: replay.c,v 1.16 2008/04/16 16:12:34 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -48,6 +48,7 @@ static replay_t	*g_replay_cur_draw;
 static bool_t	g_flg_play_replay;
 static long	g_play_replay_turn;
 static long	g_play_replay_count;
+static long	g_play_replay_char;
 
 static long	g_play_replay_idx;
 static long	g_play_replay_idx_draw;
@@ -72,11 +73,20 @@ void	init_replay( void )
 	g_flg_play_replay = FALSE;
 	g_play_replay_turn = -1;
 	g_play_replay_count = 0;
+	g_play_replay_char = '\0';
 
 	g_play_replay_idx = 0;
 	g_play_replay_idx_draw = 0;
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_replay( void )
+{
+}
+
 /***************************************************************
 * ץ쥤ꥻå
 * long n : ǡåֹ
@@ -133,16 +143,16 @@ void	bgn_reg_replay( long n )
 {
 	replay_slot_t	sn = cv_slot_n( n );
 
-	if( n != SAVE_N_AUTO )
+	if( (n != SAVE_N_AUTO) && (n != SAVE_N_BUG_REPO) )
 		g_replay_save_slot = n;
 
 	if( g_flg_reg_replay[sn] )
-		reset_replay( n );
+		reset_replay_slot( sn );
 
 	g_replay_randm_seed[sn] = get_randm_seed();
 
 	g_flg_reg_replay[sn] = TRUE;
-	if( n != SAVE_N_AUTO )
+	if( (n != SAVE_N_AUTO) && (n != SAVE_N_BUG_REPO) )
 		print_msg( FLG_NULL, MSG_BGN_REG_REPLAY );
 }
 
@@ -196,6 +206,10 @@ bool_t	set_replay_str(
 	if( !set_replay_str_slot( kind, sn, str ) )
 		flg_success = FALSE;
 
+	sn = REPLAY_SLOT_BUG_REPO;
+	if( !set_replay_str_slot( kind, sn, str ) )
+		flg_success = FALSE;
+
 	sn = cv_slot_n( g_replay_save_slot );
 	if( !set_replay_str_slot( kind, sn, str ) )
 		flg_success = FALSE;
@@ -250,6 +264,10 @@ bool_t	set_replay_char(
 	if( !set_replay_char_slot( kind, sn, c ) )
 		flg_success = FALSE;
 
+	sn = REPLAY_SLOT_BUG_REPO;
+	if( !set_replay_char_slot( kind, sn, c ) )
+		flg_success = FALSE;
+
 	sn = cv_slot_n( g_replay_save_slot );
 	if( !set_replay_char_slot( kind, sn, c ) )
 		flg_success = FALSE;
@@ -337,24 +355,23 @@ bool_t	ready_replay( replay_slot_t sn, bool_t flg_break )
 
 bool_t	get_draw_replay( char *buf, long *idx, long *len )
 {
-	bool_t	flg_redraw, flg_set_next;
 	replay_t	*p, *next_p;
 	long	n, next_n;
+	bool_t	flg_redraw, flg_set_next;
 	char	tmp[1 + 1], *tmp2;
 	long	len_tmp2;
 	long	i;
 
 	if( buf == NULL )
 		return FALSE;
-	buf[0] = '\0';
-
 	if( idx == NULL )
 		return FALSE;
-	*idx = 0;
-
 	if( len == NULL )
 		return FALSE;
-	*len = 1;
+
+	buf[0] = '\0';
+	*idx = 0;
+	*len = 0;
 
 	flg_redraw = FALSE;
 	flg_set_next = FALSE;
@@ -363,11 +380,10 @@ bool_t	get_draw_replay( char *buf, long *idx, long *len )
 	n = g_play_replay_idx_draw;
 	next_p = p;
 	next_n = n;
-
 	if( p == NULL )
 		return FALSE;
 
-	for( i = 0; i < SCREEN_WIDTH - 2; i += len_tmp2 ){
+	for( i = 0; i < SCREEN_WIDTH - 4; i += len_tmp2 ){
 		if( str_len_draw( buf ) >= SCREEN_WIDTH )
 			break;
 
@@ -379,18 +395,22 @@ bool_t	get_draw_replay( char *buf, long *idx, long *len )
 		len_tmp2 = str_len_draw( tmp2 );
 		str_max_n_cat( buf, tmp2, SCREEN_WIDTH );
 
-		if( !flg_set_next && (i == (SCREEN_WIDTH / 2)) ){
+		if( !flg_set_next && (i > (SCREEN_WIDTH / 2)) ){
 			flg_set_next = TRUE;
 			next_p = p;
 			next_n = n;
 		}
 
+		/* ֤߰ƬФǤ */
+
 		if( (p == g_replay_cur[REPLAY_SLOT_PLAY])
-				&& (n >= g_play_replay_idx)
+				&& (n > g_play_replay_idx)
 				&& (*idx == 0) ){
 			*idx = i;
 			*len = len_tmp2;
 
+			/* ̤ 3/4 ã */
+
 			if( i > (SCREEN_WIDTH * 3 / 4) ){
 				flg_redraw = TRUE;
 
@@ -399,10 +419,18 @@ bool_t	get_draw_replay( char *buf, long *idx, long *len )
 				p = next_p;
 				n = next_n;
 
+				buf[0] = '\0';
+				*idx = 0;
+				*len = 0;
+
 				i = 0 - len_tmp2;
+				continue;
 			}
 		}
 	}
+
+	if( i > SCREEN_WIDTH )
+		i = SCREEN_WIDTH;
 	buf[i] = '\0';
 
 	return flg_redraw;
@@ -410,6 +438,9 @@ bool_t	get_draw_replay( char *buf, long *idx, long *len )
 
 /***************************************************************
 * ץ쥤Υå
+* g_play_replay_turn, g_play_replay_count, g_play_replay_char
+* ΤŤѤʤ硢˸ƤФ get_replay_key 
+* ץ쥤νλ֤
 * long c : ץ쥤
 ***************************************************************/
 
@@ -418,21 +449,30 @@ void	chk_replay_key( long c )
 	if( !g_flg_play_replay )
 		return;
 
+	g_play_replay_char = '\0';
+
 	switch( c ){
-	default:
+	case CASE_EXEC:
+		g_play_replay_turn = get_turn();
+		break;
 	case CASE_ENTER:
+	default:
 		g_play_replay_count = 1;
 		break;
 	case ' ':
 		g_play_replay_count = 10;
 		break;
-	case CASE_EXEC:
-		g_play_replay_turn = get_turn();
+	case '\0':
+	case CMD_KEY_IDLE:
+		g_play_replay_char = CMD_KEY_IDLE;
+		break;
+	case CMD_KEY_CONT_EXEC:
+		toggle_continue_exec_mode();
+		g_play_replay_char = CMD_KEY_IDLE;
 		break;
 	case CASE_CANCEL:
-	case 'Q':
-	case 'Q' - '@':
-	case 'C' - '@':
+	case CASE_EXIT:
+	case CASE_SQUARE:
 		set_flg_play_replay( FALSE );
 		break;
 	}
@@ -451,13 +491,22 @@ long	get_replay_key( void )
 	if( !g_flg_play_replay )
 		return '\0';
 
+	if( g_play_replay_char != '\0' ){
+		long	c;
+
+		c = g_play_replay_char;
+		g_play_replay_char = '\0';
+
+		return c;
+	}
+
 	pp = &(g_replay_cur[REPLAY_SLOT_PLAY]);
 	idx = &g_play_replay_idx;
 
 	if( g_play_replay_turn == get_turn() )
 		return get_replay_next_key( pp, idx );
-
-	g_play_replay_turn = -1;
+	else
+		g_play_replay_turn = -1;
 
 	if( g_play_replay_count > 0 ){
 		g_play_replay_count--;
@@ -569,6 +618,8 @@ replay_slot_t	cv_slot_n( long n )
 {
 	if( n == SAVE_N_AUTO )
 		return REPLAY_SLOT_AUTO;
+	else if( n == SAVE_N_BUG_REPO )
+		return REPLAY_SLOT_BUG_REPO;
 	else
 		return REPLAY_SLOT_STD;
 }
@@ -620,6 +671,7 @@ replay_t	*alloc_replay( void )
 	p = (replay_t *)alloc_mem( sizeof( replay_t ), FALSE );
 	if( p == NULL ){
 		end_reg_replay( SAVE_N_AUTO );
+		end_reg_replay( SAVE_N_BUG_REPO );
 		end_reg_replay( g_replay_save_slot );
 
 		return NULL;
