@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: scene.c,v 1.2 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: scene.c,v 1.4 2008/05/05 12:43:44 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -50,6 +50,14 @@ void	init_scene( void )
 	scene_n = SCENE_N_NULL;
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_scene( void )
+{
+}
+
 /***************************************************************
 * ڤؤ
 ***************************************************************/
@@ -146,6 +154,9 @@ bool_t	chk_scene_group( scene_group_n_t group_n )
 		if( group_n == SCENE_GROUP_N_CAN_SKIP )
 			return TRUE;
 		break;
+	case SCENE_N_SEL_MBR_GRAPH:
+		if( group_n == SCENE_GROUP_N_SEL_GRAPH )
+			return TRUE;
 	case SCENE_N_MAX_N:
 		break;
 	}
