@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.171 2008/04/06 08:00:04 bowkenken Exp $
+* $Id: spell.c,v 1.172 2008/04/16 16:12:34 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -79,6 +79,10 @@ static pos_t	g_vfx_bgn[VFX_ARW_MAX_N], g_vfx_end[VFX_ARW_MAX_N];
 
 /**/
 
+static mbr_t	*static_cb_menu_sel_spell__pre_sel_mbr;
+
+/**/
+
 void	init_spell( void )
 {
 	long	m;
@@ -127,6 +131,38 @@ void	init_spell( void )
 	}
 }
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_spell( void )
+{
+	long	m;
+
+	/* cast_tab */
+
+	g_sel_mbr = NULL;
+	g_sel_spell = NULL;
+
+	for( m = 0; m < LS_MBR_MAX_N; m++ ){
+		long	k;
+
+		g_dflt_spell_abl[m] = NULL;
+		for( k = 0; k < ABL_KIND_MAX_N; k++ ){
+			g_dflt_spell[m][k] = NULL;
+			g_dflt_spell_extent[m][k] = NULL;
+		}
+	}
+	g_sel_spell_abl = ABL_KIND_HP;
+
+	g_vfx_n = 0;
+	/* g_vfx_bgn, g_vfx_end */;
+
+	/**/
+
+	static_cb_menu_sel_spell__pre_sel_mbr = NULL;
+}
+
 /**/
 
 void	init_spell_debug( void )
@@ -218,7 +254,7 @@ void	init_spell_nin( void )
 
 char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 {
-	static mbr_t	*pre_sel_mbr = NULL;
+	mbr_t	*pre_sel_mbr;
 	pos_t	*crsr;
 	menu_t	*ls;
 	unsigned char	key;
@@ -226,6 +262,9 @@ char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 	bool_t	flg_learn;
 	long	i;
 
+	/**/
+	pre_sel_mbr = static_cb_menu_sel_spell__pre_sel_mbr;
+
 	crsr = get_crsr();
 	g_sel_mbr = get_mbr( crsr->x, crsr->y );
 	if( g_sel_mbr == NULL ){
