@@ -4,7 +4,8 @@
 extern "C" {
 #endif
 
-void	init_tmenu( void );
+void	init_town_menu( void );
+void	reset_static_town_menu( void );
 char	*menu_shop_sel_mbr( shop_n_t shop_n, bool_t flg_pet );
 char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_temple_remove_curse( menu_t **pp, menu_t **dflt );
