@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2007 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town-tab.h,v 1.9 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: town-tab.h,v 1.11 2008/02/04 04:37:44 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TOWN_TAB_H
@@ -497,7 +497,7 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
 	},
-
+#if	0
 	{ ITEM_KIND_SCROLL, 12,
 		POTION_KIND_NULL,
 		SCROLL_KIND_POW_UP_WPN_HIT,
@@ -557,7 +557,7 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
 	},
-
+#endif
 	{ ITEM_KIND_SCROLL, 12,
 		POTION_KIND_NULL,
 		SCROLL_KIND_PROTECT_ARMOR,
