@@ -5,6 +5,7 @@ extern "C" {
 #endif
 
 long	init_turn();
+void	reset_static_turn( void );
 long	reset_turn( long n );
 long	add_turn( long n );
 long	inc_turn( void );
@@ -18,6 +19,8 @@ long	get_game_day( void );
 bool_t	chk_morning( void );
 bool_t	chk_evening( void );
 bool_t	chk_night( void );
+rate_t	get_morning_rate( void );
+rate_t	get_evening_rate( void );
 char	*get_calendar_str( void );
 char	*get_stat_time_str( void );
 char	*get_day_of_week_name( void );
